@@ -31,7 +31,7 @@ use Sim::OPT::Parcoord3d;
 our @ISA = qw( Exporter );
 our @EXPORT = qw( interlinear, interstart prepfactlev tellstepsize );
 
-$VERSION = '0.035';
+$VERSION = '0.037';
 $ABSTRACT = 'Interlinear is a program for building metamodels from incomplete, multivariate, discrete dataseries on the basis of nearest-neighbouring gradients weighted by distance.';
 
 #######################################################################
@@ -642,7 +642,7 @@ sub wei
             unless ( !keys %{ $res_ref } and ( $ordist > 0 ) and ( $ordist ne "" ) ) ######## IMPROVE THIS SO AS TO ALLOW VERY DIFFERENT NUMBERS OF LEVELS FOR EACH FACTOR
             { #say $tee " SO I AM IN. ";
 
-              my @sorteds = sort( @{ $bank{$trio}{strengths} } );
+              my @sorteds = sort { $b <=> $a } @{ $bank{$trio}{strengths} };
               my $benchmark = $sorteds[$nfilter-1];
 
               if ( ( ($nfilter) and ( $strength > $benchmark ) ) or ( not( $nfilter ) ) )
